@@ -7,7 +7,7 @@ is_linux <- function() unname(Sys.info()["sysname"] == "Linux")
 
 test_gnparser_setup <- function(bin_full_path){
   
-  if (!exec_exists(bin_full_path)) message("GNparser is not installed in your machine.")
+  if (!exec_exists(bin_full_path)) message("GNparser is not installed in your machine. Please acess xx3 to get help to install gnparser")
 }
 
 check_gnparser_setup <- function(){
@@ -36,7 +36,7 @@ check_gnparser_setup <- function(){
 #' whitespaces), and 5) parse names, i.e., separate author, date, annotations
 #' from taxon name.
 #' 
-
+#' The execution of these functions depends on the gnparser software, which is not installed automatically. Please follow this tutorial xx1 to install gnparser.
 #'
 #' @family taxonomy
 #' @param sci_names character string. Containing scientific names.
@@ -44,7 +44,10 @@ check_gnparser_setup <- function(){
 #'
 #' @details Terms denoting uncertainty or provisional status of taxonomic
 #' identification as well as infraspecific terms were obtained from Sigoviniet
-#' al. (2016; doi: 10.1111/2041-210X.12594).
+#' al. (2016; doi: 10.1111/2041-210X.12594). More details about the names
+#' parse process can be found in
+#' \href{https://github.com/gnames/gnparser}{gnparser}. 
+#' \bold{Note: GNparser is not automatically installed. Please follow this tutorial xx2 to install gnpaser}
 #'
 #' @return A five-column data.frame including
 #' * scientificName: original names supplied
@@ -732,8 +735,9 @@ bdc_rem_other_issues <- function(data, sci_names) {
   sci_names_raw <- data[[sci_names]] %>% stringr::str_squish()
 
   res <- data[[sci_names]] %>% stringr::str_squish()
-
-  # count the number of words
+  res <- stringr::str_to_lower(res) #### add here
+  
+  # count the number of res# count the number of words
   word_count <- stringr::str_count(res, "\\w+")
 
   # Convert to lower case and capitalize the only first letter of the generic
@@ -746,17 +750,18 @@ bdc_rem_other_issues <- function(data, sci_names) {
     gsub("^$", NA, res) %>% # substitute empty records by NA
     firstup(.) # Capitalize first letter
 
-  all_capitalize <- NULL
-  for (i in 1:length(res)) {
-    all_capitalize[i] <- !stringr::str_detect(res[i], "[[:lower:]]")
-  }
-
-  cap_words <- which(all_capitalize == TRUE)
-  for (i in 1:length(cap_words)) {
-    res[i] <-
-      stringr::str_to_lower(res[i]) %>%
-      firstup(.)
-  }
+  # all_capitalize <- NULL
+  # for (i in 1:length(res)) {
+  #   all_capitalize[i] <- !stringr::str_detect(res[i], "[[:lower:]]")
+  # }
+  # 
+  # # cap_words <- which(all_capitalize == TRUE)
+  # # #  for (i in 1:length(cap_words)) {
+  # # for (i in cap_words) {
+  #   res[i] <-
+  #     stringr::str_to_lower(res[i]) %>%
+  #     firstup(.)
+  # # }
 
   clean_other_issues <- res
   .other_issues <- sci_names_raw == clean_other_issues
